#
# spec file for package ghc-warp
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name warp
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        3.4.7
Release:        1.5
Summary:        A fast, light-weight web server for WAI applications
License:        MIT
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-array-devel
BuildRequires:  ghc-array-prof
BuildRequires:  ghc-async-devel
BuildRequires:  ghc-async-prof
BuildRequires:  ghc-auto-update-devel
BuildRequires:  ghc-auto-update-prof
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bsb-http-chunked-devel
BuildRequires:  ghc-bsb-http-chunked-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-case-insensitive-devel
BuildRequires:  ghc-case-insensitive-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-crypton-x509-devel
BuildRequires:  ghc-crypton-x509-prof
BuildRequires:  ghc-hashable-devel
BuildRequires:  ghc-hashable-prof
BuildRequires:  ghc-http-date-devel
BuildRequires:  ghc-http-date-prof
BuildRequires:  ghc-http-types-devel
BuildRequires:  ghc-http-types-prof
BuildRequires:  ghc-http2-devel
BuildRequires:  ghc-http2-prof
BuildRequires:  ghc-iproute-devel
BuildRequires:  ghc-iproute-prof
BuildRequires:  ghc-network-devel
BuildRequires:  ghc-network-prof
BuildRequires:  ghc-recv-devel
BuildRequires:  ghc-recv-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-simple-sendfile-devel
BuildRequires:  ghc-simple-sendfile-prof
BuildRequires:  ghc-stm-devel
BuildRequires:  ghc-stm-prof
BuildRequires:  ghc-streaming-commons-devel
BuildRequires:  ghc-streaming-commons-prof
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
BuildRequires:  ghc-time-manager-devel
BuildRequires:  ghc-time-manager-prof
BuildRequires:  ghc-unix-devel
BuildRequires:  ghc-unix-prof
BuildRequires:  ghc-vault-devel
BuildRequires:  ghc-vault-prof
BuildRequires:  ghc-wai-devel
BuildRequires:  ghc-wai-prof
BuildRequires:  ghc-word8-devel
BuildRequires:  ghc-word8-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-QuickCheck-prof
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-directory-prof
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-hspec-prof
BuildRequires:  ghc-http-client-devel
BuildRequires:  ghc-http-client-prof
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-process-prof
%endif

%description
HTTP/1.0, HTTP/1.1 and HTTP/2 are supported. For HTTP/2, Warp supports direct
and ALPN (in TLS) but not upgrade. API docs and the README are available at
<http://www.stackage.org/package/warp>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc ChangeLog.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Tue Dec  3 2024 Peter Simons <psimons@suse.com>
- Update warp to version 3.4.7.
  [#]# 3.4.7
  * Using time-manager >= 0.2.
  [#]# 3.4.6
  * Using `withHandle` of time-manager.
* Tue Nov 19 2024 Peter Simons <psimons@suse.com>
- Update warp to version 3.4.5.
  [#]# 3.4.5
  * Rethrowing asynchronous exceptions and preventing callsing
    `connClose` twice.
    [#1013](https://github.com/yesodweb/wai/pull/1013)
* Thu Nov  7 2024 Peter Simons <psimons@suse.com>
- Update warp to version 3.4.4.
  [#]# 3.4.4
  * Removing `unliftio`.
* Tue Oct 15 2024 Peter Simons <psimons@suse.com>
- Update warp to version 3.4.3.
  [#]# 3.4.3
  * Waiting untill the number of FDs desreases on EMFILE.
    [#1009](https://github.com/yesodweb/wai/pull/1009)
  [#]# 3.4.2
  * serveConnection is re-exported from the Internal module.
    [#1007](https://github.com/yesodweb/wai/pull/1007)
  [#]# 3.4.1
  * Using time-manager v0.1.0, and auto-update v0.2.0.
    [#986](https://github.com/yesodweb/wai/pull/986)
  [#]# 3.4.0
  * Reworked request lines (`CRLF`) parsing: [#968](https://github.com/yesodweb/wai/pulls)
  * We do not accept multiline headers anymore.
    ([`RFC 7230`](https://www.rfc-editor.org/rfc/rfc7230#section-3.2.4) deprecated it 10 years ago)
  * Reworked request lines (`CRLF`) parsing to not unnecessarily copy bytestrings.
  * Using http2 v5.1.0.
  * `fourmolu` is used as an official formatter.
* Fri Nov 24 2023 Peter Simons <psimons@suse.com>
- Update warp to version 3.3.31.
  [#]# 3.3.31
  * Supporting http2 v5.0.
* Wed Oct 25 2023 Peter Simons <psimons@suse.com>
- Update warp to version 3.3.30.
  [#]# 3.3.30
  * Length of `ResponseBuilder` responses will now also be passed to the logger.
    [#946](https://github.com/yesodweb/wai/pull/946)
  * Using `If-(None-)Match` headers simultaneously with `If-(Un)Modified-Since` headers now
    follow the RFC 9110 standard. So `If-(Un)Modified-Since` headers will be correctly ignored
    if their respective `-Match` counterpart is also present in the request headers.
    [#945](https://github.com/yesodweb/wai/pull/945)
  * Fixed adding superfluous `Server` header when using HTTP/2.0 if response already has it.
    [#943](https://github.com/yesodweb/wai/pull/943)
  [#]# 3.3.29
  * Preparing coming "http2" v4.2.0.
  [#]# 3.3.28
  * Fix for the "-x509" flag
    [#935](https://github.com/yesodweb/wai/pull/935)
  [#]# 3.3.27
  * Fixing busy loop due to eMFILE
    [#933](https://github.com/yesodweb/wai/pull/933)
  [#]# 3.3.26
  * Using crypton instead of cryptonite.
    [#931](https://github.com/yesodweb/wai/pull/931)
* Wed Oct 25 2023 Peter Simons <psimons@suse.com>
- Update warp to version 3.3.25 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Thu Mar 16 2023 Peter Simons <psimons@suse.com>
- Update warp to version 3.3.25.
  [#]# 3.3.25
  * Catching up the signature change of openFd in the unix package v2.8.
    [#926](https://github.com/yesodweb/wai/pull/926)
* Wed Feb  8 2023 Peter Simons <psimons@suse.com>
- Update warp to version 3.3.24.
  [#]# 3.3.24
  * Switching the version of the "recv" package from 0.0.x to 0.1.x.
* Thu Jan 26 2023 Peter Simons <psimons@suse.com>
- Update warp to version 3.3.23 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Wed Sep 28 2022 Peter Simons <psimons@suse.com>
- Update warp to version 3.3.23.
  [#]# 3.3.23
  * Add `setAccept` for hooking the socket `accept` call.
    [#912](https://github.com/yesodweb/wai/pull/912)
  * Removed some package dependencies from test suite
    [#902](https://github.com/yesodweb/wai/pull/902)
  * Factored out `Network.Wai.Handler.Warp.Recv` to its own package `recv`.
    [#899](https://github.com/yesodweb/wai/pull/899)
* Tue Aug  9 2022 Peter Simons <psimons@suse.com>
- Update warp to version 3.3.22.
  [#]# 3.3.22
  * Creating a bigger buffer when the current one is too small to fit the Builder
    [#895](https://github.com/yesodweb/wai/pull/895)
  * Using InvalidRequest instead of HTTP2Error
    [#890](https://github.com/yesodweb/wai/pull/890)
* Mon May 30 2022 Peter Simons <psimons@suse.com>
- Update warp to version 3.3.21.
  [#]# 3.3.21
  * Support GHC 9.4 [#889](https://github.com/yesodweb/wai/pull/889)
* Mon Mar  7 2022 Peter Simons <psimons@suse.com>
- Update warp to version 3.3.20.
  [#]# 3.3.20
  * Adding "x509" flag.
    [#871](https://github.com/yesodweb/wai/pull/871)
* Wed Feb  2 2022 Peter Simons <psimons@suse.com>
- Update warp to version 3.3.19.
  [#]# 3.3.19
  * Allowing the eMFILE exception in acceptNewConnection.
    [#831](https://github.com/yesodweb/wai/pull/831)
* Sat Nov 20 2021 psimons@suse.com
- Update warp to version 3.3.18.
  [#]# 3.3.18
  * Tidy up HashMap and MultiMap [#864](https://github.com/yesodweb/wai/pull/864)
  * Support GHC 9.2 [#863](https://github.com/yesodweb/wai/pull/863)
* Tue Jun 22 2021 psimons@suse.com
- Update warp to version 3.3.17.
  [#]# 3.3.17
  * Modify exception handling to swallow async exceptions in forked thread [#850](https://github.com/yesodweb/wai/issues/850)
  * Switch default forking function to not install the global exception handler (minor optimization) [#851](https://github.com/yesodweb/wai/pull/851)
* Wed May 26 2021 psimons@suse.com
- Update warp to version 3.3.16.
  [#] ChangeLog for warp
  [#]# 3.3.16
  * Move exception handling over to `unliftio` for better async exception support [#845](https://github.com/yesodweb/wai/issues/845)
* Fri Apr 16 2021 psimons@suse.com
- Update warp to version 3.3.15.
  [#]# 3.3.15
  * Using http2 v3.
* Thu Feb  4 2021 psimons@suse.com
- Update warp to version 3.3.14.
  [#]# 3.3.14
  * Drop support for GHC < 8.2.
  * Fix header length calculation for `settingsMaxTotalHeaderLength`
    [#838](https://github.com/yesodweb/wai/pull/838)
  * UTF-8 encoding in `exceptionResponseForDebug`.
    [#836](https://github.com/yesodweb/wai/pull/836)
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Fri Jun 26 2020 psimons@suse.com
- Update warp to version 3.3.13.
  [#]# 3.3.13
  * pReadMaker is exported from the Internal module.
* Tue Jun  9 2020 psimons@suse.com
- Add warp at version 3.3.12.
